]> sigrok.org Git - libsigrok.git/commitdiff
sr: rename all sr_device_* functions to sr_dev_*
authorBert Vermeulen <redacted>
Mon, 13 Feb 2012 13:00:47 +0000 (14:00 +0100)
committerBert Vermeulen <redacted>
Mon, 13 Feb 2012 13:00:47 +0000 (14:00 +0100)
14 files changed:
device.c
hwplugin.c
input/binary.c
input/chronovu_la8.c
output/analog.c
output/chronovu_la8.c
output/csv.c
output/gnuplot.c
output/ols.c
output/text/text.c
output/vcd.c
session_driver.c
session_file.c
sigrok-proto.h

index e3543d5345701cfad7f16a138bdf5c35bd13125e..491317a55d8ad1905de48a56dc15aeaf88349295 100644 (file)
--- a/device.c
+++ b/device.c
@@ -50,14 +50,14 @@ static GSList *devices = NULL;
  * caller should not assume or rely on any specific order.
  *
  * After the system has been scanned for devices, the list of detected (and
* supported) devices can be acquired via sr_device_list().
  *
  * TODO: Error checks?
  * TODO: Option to only scan for specific devices or device classes.
  *
  * @return SR_OK upon success, SR_ERR upon errors.
  */
-SR_API int sr_device_scan(void)
+SR_API int sr_dev_scan(void)
 {
        GSList *plugins, *l;
        struct sr_device_plugin *plugin;
@@ -85,16 +85,16 @@ SR_API int sr_device_scan(void)
  * Return the list of logic analyzer devices libsigrok has detected.
  *
  * If the libsigrok-internal device list is empty, a scan for attached
* devices -- via a call to sr_device_scan() -- is performed first.
  *
  * TODO: Error handling?
  *
  * @return The list (GSList) of detected devices, or NULL if none were found.
  */
-SR_API GSList *sr_device_list(void)
+SR_API GSList *sr_dev_list(void)
 {
        if (!devices)
-               sr_device_scan();
+               sr_dev_scan();
 
        return devices;
 }
@@ -106,7 +106,7 @@ SR_API GSList *sr_device_list(void)
  * additionally a pointer to the newly created device is also returned.
  *
  * The device has no probes attached to it yet after this call. You can
* use sr_device_probe_add() to add one or more probes.
  *
  * TODO: Should return int, so that we can return SR_OK, SR_ERR_* etc.
  *
@@ -119,7 +119,7 @@ SR_API GSList *sr_device_list(void)
  *
  * @return Pointer to the newly allocated device, or NULL upon errors.
  */
-SR_API struct sr_device *sr_device_new(const struct sr_device_plugin *plugin,
+SR_API struct sr_device *sr_dev_new(const struct sr_device_plugin *plugin,
                                       int plugin_index)
 {
        struct sr_device *device;
@@ -144,7 +144,7 @@ SR_API struct sr_device *sr_device_new(const struct sr_device_plugin *plugin,
  * The added probe is automatically enabled (the 'enabled' field is TRUE).
  *
  * The 'trigger' field of the added probe is set to NULL. A trigger can be
- * added via sr_device_trigger_set().
+ * added via sr_dev_trigger_set().
  *
  * TODO: Are duplicate names allowed?
  * TODO: Do we enforce a maximum probe number for a device?
@@ -160,7 +160,7 @@ SR_API struct sr_device *sr_device_new(const struct sr_device_plugin *plugin,
  *         or SR_ERR_ARG upon invalid arguments.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_probe_add(struct sr_device *device, const char *name)
+SR_API int sr_dev_probe_add(struct sr_device *device, const char *name)
 {
        struct sr_probe *p;
        int probenum;
@@ -208,7 +208,7 @@ SR_API int sr_device_probe_add(struct sr_device *device, const char *name)
  * @return A pointer to the requested probe's 'struct sr_probe', or NULL
  *         if the probe could not be found.
  */
-SR_API struct sr_probe *sr_device_probe_find(const struct sr_device *device,
+SR_API struct sr_probe *sr_dev_probe_find(const struct sr_device *device,
                                             int probenum)
 {
        GSList *l;
@@ -251,7 +251,7 @@ SR_API struct sr_probe *sr_device_probe_find(const struct sr_device *device,
  *         upon other errors.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
+SR_API int sr_dev_probe_name(struct sr_device *device, int probenum,
                                const char *name)
 {
        struct sr_probe *p;
@@ -261,7 +261,7 @@ SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
                return SR_ERR_ARG;
        }
 
-       p = sr_device_probe_find(device, probenum);
+       p = sr_dev_probe_find(device, probenum);
        if (!p) {
                sr_err("dev: %s: probe %d not found", __func__, probenum);
                return SR_ERR; /* TODO: More specific error? */
@@ -287,7 +287,7 @@ SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_trigger_clear(struct sr_device *device)
+SR_API int sr_dev_trigger_clear(struct sr_device *device)
 {
        struct sr_probe *p;
        unsigned int pnum; /* TODO: uint16_t? */
@@ -303,7 +303,7 @@ SR_API int sr_device_trigger_clear(struct sr_device *device)
        }
 
        for (pnum = 1; pnum <= g_slist_length(device->probes); pnum++) {
-               p = sr_device_probe_find(device, pnum);
+               p = sr_dev_probe_find(device, pnum);
                /* TODO: Silently ignore probes which cannot be found? */
                if (p) {
                        g_free(p->trigger);
@@ -330,7 +330,7 @@ SR_API int sr_device_trigger_clear(struct sr_device *device)
  *         upon other errors.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
+SR_API int sr_dev_trigger_set(struct sr_device *device, int probenum,
                                 const char *trigger)
 {
        struct sr_probe *p;
@@ -344,7 +344,7 @@ SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
 
        /* TODO: Sanity check on 'trigger'. */
 
-       p = sr_device_probe_find(device, probenum);
+       p = sr_dev_probe_find(device, probenum);
        if (!p) {
                sr_err("dev: %s: probe %d not found", __func__, probenum);
                return SR_ERR; /* TODO: More specific error? */
@@ -372,7 +372,7 @@ SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
  *         FALSE is also returned upon invalid input parameters or other
  *         error conditions.
  */
-SR_API gboolean sr_device_has_hwcap(const struct sr_device *device, int hwcap)
+SR_API gboolean sr_dev_has_hwcap(const struct sr_device *device, int hwcap)
 {
        int *capabilities, i;
 
@@ -416,7 +416,7 @@ SR_API gboolean sr_device_has_hwcap(const struct sr_device *device, int hwcap)
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or SR_ERR
  *         upon other errors.
  */
-int sr_device_get_info(const struct sr_device *device, int id,
+int sr_dev_get_info(const struct sr_device *device, int id,
                                           const void **data)
 {
        if ((device == NULL) || (device->plugin == NULL))
index dfee3814bd32e4ce6533db4fc052b04fa5d42b71..a12501f0e8793de84999454245d0886b3284ba92 100644 (file)
@@ -145,9 +145,9 @@ SR_API int sr_init_hwplugin(struct sr_device_plugin *plugin)
                        continue;
                }
 
-               device = sr_device_new(plugin, i);
+               device = sr_dev_new(plugin, i);
                for (j = 0; j < num_probes; j++)
-                       sr_device_probe_add(device, probe_names[j]);
+                       sr_dev_probe_add(device, probe_names[j]);
                num_initialized_devices++;
        }
 
index f00a14b89a50272c62b40eedf0bab9c5dd8c4723..4ea77b23d44a5ca32c94ebf7362651feea1d7953 100644 (file)
@@ -51,12 +51,12 @@ static int init(struct sr_input *in)
        }
 
        /* Create a virtual device. */
-       in->vdevice = sr_device_new(NULL, 0);
+       in->vdevice = sr_dev_new(NULL, 0);
 
        for (i = 0; i < num_probes; i++) {
                snprintf(name, SR_MAX_PROBENAME_LEN, "%d", i);
                /* TODO: Check return value. */
-               sr_device_probe_add(in->vdevice, name);
+               sr_dev_probe_add(in->vdevice, name);
        }
 
        return SR_OK;
index e1b6ad10d93229324a9968cd2a910c8147ca3661..10653073b96b23b53dd2a059d52e94e9ce8bb14e 100644 (file)
@@ -91,12 +91,12 @@ static int init(struct sr_input *in)
        }
 
        /* Create a virtual device. */
-       in->vdevice = sr_device_new(NULL, 0);
+       in->vdevice = sr_dev_new(NULL, 0);
 
        for (i = 0; i < num_probes; i++) {
                snprintf(name, SR_MAX_PROBENAME_LEN, "%d", i);
                /* TODO: Check return value. */
-               sr_device_probe_add(in->vdevice, name);
+               sr_dev_probe_add(in->vdevice, name);
        }
 
        return SR_OK;
index c59399a27847167a1bb2335732d876643809a15d..a0b81119102ff75436dcec7d0c168d50edea0a6c 100644 (file)
@@ -135,7 +135,7 @@ static int init(struct sr_output *o, int default_spl, enum outputmode mode)
 
        snprintf(ctx->header, 511, "%s\n", PACKAGE_STRING);
        num_probes = g_slist_length(o->device->probes);
-       if (o->device->plugin && sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (o->device->plugin && sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                if (!(samplerate_s = sr_samplerate_string(samplerate))) {
index 993d29fcdcf3e6169219c45d41bc5597deebfb54..830f42695552c1ac0d702d84008a114acf91c139 100644 (file)
@@ -122,7 +122,7 @@ static int init(struct sr_output *o)
 
        num_probes = g_slist_length(o->device->probes);
 
-       if (sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                /* TODO: Error checks. */
index 2f91226ba8620cfa664dd23ce442ec8da7f5d32e..c1b0ee9247db00e0aac88f199e5a97570147a09b 100644 (file)
@@ -91,7 +91,7 @@ static int init(struct sr_output *o)
 
        num_probes = g_slist_length(o->device->probes);
 
-       if (sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                /* TODO: Error checks. */
index cfb5d7ec4ab3bf319bd84f325150c3f83bb07453..1107d226f3d778e61f6e4408c7b1539bd8f57716 100644 (file)
@@ -100,7 +100,7 @@ static int init(struct sr_output *o)
 
        num_probes = g_slist_length(o->device->probes);
        comment[0] = '\0';
-       if (sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                if (!(frequency_s = sr_samplerate_string(samplerate))) {
@@ -324,7 +324,7 @@ static int analog_init(struct sr_output *o)
 
        num_probes = g_slist_length(o->device->probes);
        comment[0] = '\0';
-       if (o->device->plugin && sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (o->device->plugin && sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                if (!(frequency_s = sr_samplerate_string(samplerate))) {
index dff54a42d607abab3ad7d904551363a942311b04..7c98a8a9d4f900341bb937476563d6a675dc37ee 100644 (file)
@@ -60,7 +60,7 @@ static int init(struct sr_output *o)
        }
        ctx->unitsize = (num_enabled_probes + 7) / 8;
 
-       if (o->device->plugin && sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE))
+       if (o->device->plugin && sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE))
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
        else
index 10ce0767da46fdd9c22dcfc44a8212c56615daa6..4267c5b0021ac21aa43f9249ff6483828e4b276f 100644 (file)
@@ -110,7 +110,7 @@ SR_PRIV int init(struct sr_output *o, int default_spl, enum outputmode mode)
 
        snprintf(ctx->header, 511, "%s\n", PACKAGE_STRING);
        num_probes = g_slist_length(o->device->probes);
-       if (o->device->plugin || sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (o->device->plugin || sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                if (!(samplerate_s = sr_samplerate_string(samplerate))) {
index c5a6bb2022ef541ec3fc98a8ef770f4b12f2f1dd..1d333c6c56466ca7ad6411a06403b45375f6379b 100644 (file)
@@ -84,7 +84,7 @@ static int init(struct sr_output *o)
        g_string_append_printf(ctx->header, "$version %s %s $end\n",
                        PACKAGE, PACKAGE_VERSION);
 
-       if (o->device->plugin && sr_device_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
+       if (o->device->plugin && sr_dev_has_hwcap(o->device, SR_HWCAP_SAMPLERATE)) {
                ctx->samplerate = *((uint64_t *) o->device->plugin->get_device_info(
                                o->device->plugin_index, SR_DI_CUR_SAMPLERATE));
                if (!((samplerate_s = sr_samplerate_string(ctx->samplerate)))) {
index 7ca8d353a4955de1b30bc5a209a651e918f651cb..117d6a251c7183dbd49fbd9c7b796277eceeaa23 100644 (file)
@@ -214,7 +214,7 @@ static int hw_get_status(int device_index)
        /* Avoid compiler warnings. */
        (void)device_index;
 
-       if (sr_device_list() != NULL)
+       if (sr_dev_list() != NULL)
                return SR_OK;
        else
                return SR_ERR;
index cb99bf27ad3f4367fb97529225db63a787fca405..e7784222f3f27c82c2428603c7aa375a6aa2e618 100644 (file)
@@ -114,7 +114,7 @@ SR_API int sr_session_load(const char *filename)
                        for (j = 0; keys[j]; j++) {
                                val = g_key_file_get_string(kf, sections[i], keys[j], NULL);
                                if (!strcmp(keys[j], "capturefile")) {
-                                       device = sr_device_new(&session_driver, devcnt);
+                                       device = sr_dev_new(&session_driver, devcnt);
                                        if (devcnt == 0)
                                                /* first device, init the plugin */
                                                device->plugin->init((char *)filename);
@@ -132,17 +132,17 @@ SR_API int sr_session_load(const char *filename)
                                        device->plugin->set_configuration(devcnt, SR_HWCAP_CAPTURE_NUM_PROBES, &total_probes);
                                        for (p = 0; p < total_probes; p++) {
                                                snprintf(probename, SR_MAX_PROBENAME_LEN, "%" PRIu64, p);
-                                               sr_device_probe_add(device, probename);
+                                               sr_dev_probe_add(device, probename);
                                        }
                                } else if (!strncmp(keys[j], "probe", 5)) {
                                        if (!device)
                                                continue;
                                        enabled_probes++;
                                        tmp_u64 = strtoul(keys[j]+5, NULL, 10);
-                                       sr_device_probe_name(device, tmp_u64, val);
+                                       sr_dev_probe_name(device, tmp_u64, val);
                                } else if (!strncmp(keys[j], "trigger", 7)) {
                                        probenum = strtoul(keys[j]+7, NULL, 10);
-                                       sr_device_trigger_set(device, probenum, val);
+                                       sr_dev_trigger_set(device, probenum, val);
                                }
                        }
                        g_strfreev(keys);
@@ -225,7 +225,7 @@ int sr_session_save(const char *filename)
                        fprintf(meta, "capturefile = logic-%d\n", devcnt);
                        fprintf(meta, "unitsize = %d\n", ds->ds_unitsize);
                        fprintf(meta, "total probes = %d\n", g_slist_length(device->probes));
-                       if (sr_device_has_hwcap(device, SR_HWCAP_SAMPLERATE)) {
+                       if (sr_dev_has_hwcap(device, SR_HWCAP_SAMPLERATE)) {
                                samplerate = *((uint64_t *) device->plugin->get_device_info(
                                                device->plugin_index, SR_DI_CUR_SAMPLERATE));
                                s = sr_samplerate_string(samplerate);
index 0efdaeec71b84bc1300f87f6dba2154bcfe8bfb1..daf92c489c4d5d9d500ae680f0b1e32909d505a5 100644 (file)
@@ -47,20 +47,20 @@ SR_API int sr_datastore_put(struct sr_datastore *ds, void *data,
 
 /*--- device.c --------------------------------------------------------------*/
 
-SR_API int sr_device_scan(void);
-SR_API GSList *sr_device_list(void);
-SR_API struct sr_device *sr_device_new(const struct sr_device_plugin *plugin,
+SR_API int sr_dev_scan(void);
+SR_API GSList *sr_dev_list(void);
+SR_API struct sr_device *sr_dev_new(const struct sr_device_plugin *plugin,
                                       int plugin_index);
-SR_API int sr_device_probe_add(struct sr_device *device, const char *name);
-SR_API struct sr_probe *sr_device_probe_find(const struct sr_device *device,
+SR_API int sr_dev_probe_add(struct sr_device *device, const char *name);
+SR_API struct sr_probe *sr_dev_probe_find(const struct sr_device *device,
                                             int probenum);
-SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
+SR_API int sr_dev_probe_name(struct sr_device *device, int probenum,
                                const char *name);
-SR_API int sr_device_trigger_clear(struct sr_device *device);
-SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
+SR_API int sr_dev_trigger_clear(struct sr_device *device);
+SR_API int sr_dev_trigger_set(struct sr_device *device, int probenum,
                                 const char *trigger);
-SR_API gboolean sr_device_has_hwcap(const struct sr_device *device, int hwcap);
-SR_API int sr_device_get_info(const struct sr_device *device, int id,
+SR_API gboolean sr_dev_has_hwcap(const struct sr_device *device, int hwcap);
+SR_API int sr_dev_get_info(const struct sr_device *device, int id,
                              const void **data);
 
 /*--- filter.c --------------------------------------------------------------*/
@@ -50,14 +50,14 @@ static GSList *devices = NULL;
  *
  * After the system has been scanned for devices, the list of detected (and
- * supported) devices can be acquired via sr_device_list().
+ * supported) devices can be acquired via sr_dev_list().
  *
  * TODO: Error checks?
@@ -85,16 +85,16 @@ SR_API int sr_device_scan(void)
  *
  * If the libsigrok-internal device list is empty, a scan for attached
- * devices -- via a call to sr_device_scan() -- is performed first.
+ * devices -- via a call to sr_dev_scan() -- is performed first.
  *
  * TODO: Error handling?
@@ -106,7 +106,7 @@ SR_API GSList *sr_device_list(void)
  *
  * The device has no probes attached to it yet after this call. You can
- * use sr_device_probe_add() to add one or more probes.
+ * use sr_dev_probe_add() to add one or more probes.
  *
  * TODO: Should return int, so that we can return SR_OK, SR_ERR_* etc.